"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findOrCreateContainerLayer = exports.getPageFromRange = exports.getPageFromElement = void 0;

var getPageFromElement = function getPageFromElement(target) {
  var node = target.closest(".page");

  if (!(node instanceof HTMLElement)) {
    return null;
  }

  var number = Number(node.dataset.pageNumber);
  return {
    node: node,
    number: number
  };
};

exports.getPageFromElement = getPageFromElement;

var getPageFromRange = function getPageFromRange(range) {
  var parentElement = range.startContainer.parentElement;

  if (!(parentElement instanceof HTMLElement)) {
    return;
  }

  return getPageFromElement(parentElement);
};

exports.getPageFromRange = getPageFromRange;

var findOrCreateContainerLayer = function findOrCreateContainerLayer(container, className) {
  var layer = container.querySelector(".".concat(className));

  if (!layer) {
    layer = document.createElement("div");
    layer.className = className;
    container.appendChild(layer);
  }

  return layer;
};

exports.findOrCreateContainerLayer = findOrCreateContainerLayer;